@@ -3,6 +3,6 @@ use insta::assert_debug_snapshot;
 
 #[test]
 fn it_works() {
-    let fixture = include_str!("fixtures/lx.fln");
+    let fixture = include_bytes!("fixtures/lx.fln");
     assert_debug_snapshot!(decode_file(fixture));
 }
