@@ -1,9 +1,8 @@
 use flarmnet::lx::{decode_file, encode_file};
-use insta::assert_debug_snapshot;
 
 #[test]
 fn it_works() {
-    let fixture = include_str!("fixtures/lx.fln");
+    let fixture = include_bytes!("fixtures/lx.fln");
     let decoded = decode_file(fixture).unwrap();
     let file = flarmnet::File {
         version: decoded.version,
@@ -13,5 +12,5 @@ fn it_works() {
             .filter_map(|it| it.ok())
             .collect(),
     };
-    assert_debug_snapshot!(encode_file(&file));
+    assert_eq!(encode_file(&file).unwrap(), fixture);
 }
